==> eiffelstudio-16.05.tar: F_code/C21/xm1008.c <==
/*
 * Code for class XM_XPATH_TIMEZONE_FROM_DATE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm1008.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_TIMEZONE_FROM_DATE}.make */
void F1879_18954 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	tr1 = RTMS_EX_H("timezone-from-date",18,1588139365);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_9_) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(9324,F1146_9324,(Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_38_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1891L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_38_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_38_0_5_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	{
		static EIF_TYPE_INDEX typarr0[] = {1438,1790,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1439_11826(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr2 = RTOSCF(3629,F598_3629,(Current));
	F1381_11416(RTCW(tr1), tr2);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_11_37_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XPATH_TIMEZONE_FROM_DATE}.item_type */
EIF_REFERENCE F1879_18955 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(9768,F1151_9768,(RTCV(RTOSCF(3631,F600_3631,(Current)))));
	if ((EIF_BOOLEAN)(Result != NULL)) {
	}
	RTLE;
	return Result;
}

/* {XM_XPATH_TIMEZONE_FROM_DATE}.required_type */
EIF_REFERENCE F1879_18956 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1722, 0x00).id, 1722, _OBJSIZ_1_37_0_0_0_0_0_0_);
	F1723_16387(RTCW(tr1));
	RTLE;
	return (EIF_REFERENCE) tr1;
}

/* {XM_XPATH_TIMEZONE_FROM_DATE}.evaluate_item */
void F1879_18957 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(10);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,arg2);
	RTLR(4,loc4);
	RTLR(5,loc1);
	RTLR(6,loc5);
	RTLR(7,loc3);
	RTLR(8,loc2);
	RTLR(9,tr2);
	RTLIU(10);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr1 = F1439_11832(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R13625[Dtype(tr1)-1791])(RTCW(tr1), arg1, arg2);
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R13075[Dtype(loc4)-1742])(loc4);
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13095[Dtype(loc4)-1741])(loc4);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13678[Dtype(loc1)-1790])(RTCW(loc1));
		tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_10_37_);
		if (tb1) {
			RTCT0("zoned", EX_CHECK);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
			loc5 = tr1;
			if (EIF_TEST(loc5)) {
				RTCK0;
			} else {
				RTCF0;
			}
			tr1 = RTLNS(eif_new_type(1537, 0x00).id, 1537, _OBJSIZ_0_0_0_3_0_0_0_0_);
			F1538_12978(RTCW(tr1), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
			loc3 = (EIF_REFERENCE) tr1;
			tr1 = RTLNS(eif_new_type(1543, 0x00).id, 1543, _OBJSIZ_0_0_0_7_0_0_0_0_);
			tr2 = *(EIF_REFERENCE *)(loc5);
			tr2 = *(EIF_REFERENCE *)(RTCW(tr2));
			F1544_13147(RTCW(tr1), loc3, tr2);
			loc2 = (EIF_REFERENCE) tr1;
			tr1 = RTLNS(eif_new_type(1809, 0x00).id, 1809, _OBJSIZ_8_37_0_1_0_0_0_0_);
			F1810_17911(RTCW(tr1), loc2);
			F193_1656(RTCW(arg1), tr1);
		} else {
			F193_1656(RTCW(arg1), NULL);
		}
	}
	RTLE;
}

/* {XM_XPATH_TIMEZONE_FROM_DATE}.compute_cardinality */
void F1879_18958 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F1044_7618(Current);
}

void EIF_Minit1008 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C21/xm1008.c <==
/*
 * Code for class XM_XPATH_TIMEZONE_FROM_TIME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm1008.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_TIMEZONE_FROM_TIME}.make */
void F1879_18986 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	tr1 = RTMS_EX_H("timezone-from-time",18,1857097317);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_9_) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(9582,F1198_9582,(Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_38_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1893L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_38_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_38_0_5_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	{
		static EIF_TYPE_INDEX typarr0[] = {1438,1790,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1439_11850(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr2 = RTOSCF(3862,F647_3862,(Current));
	F1381_11440(RTCW(tr1), tr2);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_11_37_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XPATH_TIMEZONE_FROM_TIME}.item_type */
EIF_REFERENCE F1879_18987 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(10026,F1203_10026,(RTCV(RTOSCF(3864,F649_3864,(Current)))));
	if ((EIF_BOOLEAN)(Result != NULL)) {
	}
	RTLE;
	return Result;
}

/* {XM_XPATH_TIMEZONE_FROM_TIME}.required_type */
EIF_REFERENCE F1879_18988 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1723, 0x00).id, 1723, _OBJSIZ_1_37_0_0_0_0_0_0_);
	F1724_16432(RTCW(tr1));
	RTLE;
	return (EIF_REFERENCE) tr1;
}

/* {XM_XPATH_TIMEZONE_FROM_TIME}.evaluate_item */
void F1879_18989 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(10);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,arg2);
	RTLR(4,loc4);
	RTLR(5,loc1);
	RTLR(6,loc5);
	RTLR(7,loc3);
	RTLR(8,loc2);
	RTLR(9,tr2);
	RTLIU(10);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr1 = F1439_11856(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R13608[Dtype(tr1)-1791])(RTCW(tr1), arg1, arg2);
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R13058[Dtype(loc4)-1742])(loc4);
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13078[Dtype(loc4)-1741])(loc4);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13662[Dtype(loc1)-1790])(RTCW(loc1));
		tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_10_37_);
		if (tb1) {
			RTCT0("zoned", EX_CHECK);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
			loc5 = tr1;
			if (EIF_TEST(loc5)) {
				RTCK0;
			} else {
				RTCF0;
			}
			tr1 = RTLNS(eif_new_type(1537, 0x00).id, 1537, _OBJSIZ_0_0_0_3_0_0_0_0_);
			F1538_13007(RTCW(tr1), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
			loc3 = (EIF_REFERENCE) tr1;
			tr1 = RTLNS(eif_new_type(1543, 0x00).id, 1543, _OBJSIZ_0_0_0_7_0_0_0_0_);
			tr2 = *(EIF_REFERENCE *)(loc5);
			tr2 = *(EIF_REFERENCE *)(RTCW(tr2));
			F1544_13176(RTCW(tr1), loc3, tr2);
			loc2 = (EIF_REFERENCE) tr1;
			tr1 = RTLNS(eif_new_type(1809, 0x00).id, 1809, _OBJSIZ_8_37_0_1_0_0_0_0_);
			F1810_17942(RTCW(tr1), loc2);
			F194_1687(RTCW(arg1), tr1);
		} else {
			F194_1687(RTCW(arg1), NULL);
		}
	}
	RTLE;
}

/* {XM_XPATH_TIMEZONE_FROM_TIME}.compute_cardinality */
void F1879_18990 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F1093_7838(Current);
}

void EIF_Minit1008 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
